import traceback, copy
import adagenes.tools.module_requests as req
from onkopus.conf import read_config as config
import adagenes as ag
import onkopus as op


class UTAAdapterProteinSequenceClient:

    def __init__(self, genome_version, error_logfile=None):
        self.genome_version = genome_version
        self.info_lines = config.uta_adapter_protein_sequence_info_lines
        self.url_pattern = config.uta_adapter_protein_sequence_src
        self.srv_prefix = config.uta_adapter_protein_sequence_srv_prefix
        self.genomic_keys = config.uta_genomic_keys
        self.gene_keys = config.uta_gene_keys
        self.gene_response_keys = config.uta_gene_response_keys
        self.extract_keys = config.uta_adapter_protein_sequence_keys

        self.qid_key = "q_id"
        if (self.genome_version == "hg19") or (self.genome_version == "GRCh37"):
            self.qid_key = "q_id_hg19"

    def process_data(self, data, gene_request=False):
        vcf_linesf = ag.tools.filter_wildtype_variants(data)

        retransform = False
        if self.genome_version == "hg38":
            qid_list0 = copy.deepcopy(list(vcf_linesf.keys()))
        else:
            qid_dc, qid_list0 = ag.tools.generate_qid_list_from_other_reference_genome(vcf_linesf)
            self.genome_version = "hg38"
            retransform = True

        qid_list = []
        genes = []
        variants = []
        qid_gene_name_dc = {}
        qid_list = []
        for var in qid_list0:

            if retransform is False:
                var_orig = var
            else:
                qid_orig = qid_dc[var]
                var_orig = qid_orig
            #print("var ", var, ": ", data[var_orig])

            if "UTA_Adapter" in data[var_orig]:
                if "gene_name" in data[var_orig]["UTA_Adapter"]:
                    genes.append(data[var_orig]["UTA_Adapter"]["gene_name"])
                    variants.append(data[var_orig]["UTA_Adapter"]["variant_exchange"])
                    #qid_list.append(var)
                    qid_gene_name_dc[data[var_orig]["UTA_Adapter"]["gene_name"] + ':' + data[var_orig]["UTA_Adapter"][
                        "variant_exchange"]] = [var]
                    qid_list.append(data[var_orig]["UTA_Adapter"]["gene_name"] + ':' + data[var_orig]["UTA_Adapter"][
                        "variant_exchange"])
                else:
                    pass
            elif "UTA_Adapter_gene_name" in data[var_orig].keys():
                genes.append(data[var_orig]["UTA_Adapter_gene_name"])
                variants.append(data[var_orig]["UTA_Adapter_variant_exchange"])
                #qid_list.append(var)
                qid_gene_name_dc[data[var_orig]["UTA_Adapter_gene_name"] + ':' + data[var_orig]["UTA_Adapter_variant_exchange"]] = [var]
                qid_list.append(data[var_orig]["UTA_Adapter_gene_name"] + ':' + data[var_orig]["UTA_Adapter_variant_exchange"])
            elif "hgnc_gene_symbol" in data[var_orig].keys():
                genes.append(data[var_orig]["hgnc_gene_symbol"])
                variants.append(data[var_orig]["aa_exchange"])
                #qid_list.append(var)
                qid_gene_name_dc[data[var_orig]["hgnc_gene_symbol"] + ':' + data[var_orig]["aa_exchange"]] = [var]
                qid_list.append(data[var_orig]["hgnc_gene_symbol"] + ':' + data[var_orig]["aa_exchange"])
            # elif "INFO" in data[var].keys():
            #    pass
            elif "info_features" in data[var_orig].keys():
                # print("INFO ok")
                # print(data[var]["info_features"])
                if "UTA_Adapter_gene_name" in data[var_orig]["info_features"]:
                    genes.append(data[var_orig]["info_features"]["UTA_Adapter_gene_name"])
                    variants.append(data[var_orig]["info_features"]["UTA_Adapter_variant_exchange"])
                    #qid_list.append(var)
                    qid_gene_name_dc[data[var_orig]["info_features"]["UTA_Adapter_gene_name"] + ':' + data[var_orig]["info_features"]["UTA_Adapter_variant_exchange"]] = [var]
                    qid_list.append(data[var_orig]["info_features"]["UTA_Adapter_gene_name"] + ':' + data[var_orig]["info_features"]["UTA_Adapter_variant_exchange"])
            elif "mdesc" in data[var_orig].keys():
                if data[var_orig]["mdesc"] == "gene_name":
                    qid_gene_name_dc[var_orig] = [var_orig]
                    qid_list.append(var_orig)
            # else:
            #    print("HMM","keys ",data[var])

        qid_lists_query = ag.tools.split_list(qid_list)
        genes_lists_query = ag.tools.split_list(genes)
        variants_lists_query = ag.tools.split_list(variants)
        #print("q query ",qid_lists_query)

        for q_list in qid_lists_query:
            q = ",".join(q_list).rstrip(",")


            try:
                print("q ",q)
                json_body = req.get_connection(q, self.url_pattern, self.genome_version)

                for key in json_body[0].keys():
                        if gene_request is False:
                            if str(json_body[0][key]["header"]["qid"]) in qid_gene_name_dc.keys():
                                qid = qid_gene_name_dc[str(json_body[0][key]["header"]["qid"])]
                        else:
                            #qid_index = q_list.index(str(json_body[0][key]["header"]["qid"]))
                            #qid = qids_partial[qid_index]
                            qid = str(json_body[0][key]["header"]["qid"])
                            qid = qid_gene_name_dc[qid]
                            #print("genompos for ",str(json_body[0][key]["header"]["qid"]),": ",qid)

                        if json_body[0][key]["data"] is not None:
                            if type(json_body[0][key]["data"]) is dict:
                                #print("available qids: ",list(vcf_lines.keys()))
                                #print(type(qid),",",qid)
                                if isinstance(qid, str):
                                    if retransform is False:
                                        data[qid][self.srv_prefix] = json_body[0][key]["data"]
                                    else:
                                        qid_orig = qid_dc[qid]
                                        data[qid_orig][self.srv_prefix] = json_body[0][key]["data"]
                                elif isinstance(qid, list):
                                    for q in qid:
                                        if retransform is False:
                                            data[q][self.srv_prefix] = json_body[0][key]["data"]
                                        else:
                                            qid_orig = qid_dc[q]
                                            data[qid_orig][self.srv_prefix] = json_body[0][key]["data"]
                            else:
                                data[qid][self.srv_prefix] = {}
                                data[qid][self.srv_prefix]["status"] = 400
                                data[qid][self.srv_prefix]["msg"] = json_body[0][key]["data"]
            except:
                print("error: genomic to gene")
                print(traceback.format_exc())

        return data



import time
import unittest, os
import onkopus


class TestCLIAnnotation(unittest.TestCase):
#

    def test_cli_annotation(self):
        start = time.time()
        __location__ = os.path.realpath(
            os.path.join(os.getcwd(), os.path.dirname(__file__)))
        infile = __location__ + "/../test_files/somaticMutations.vcf"
        outfile = infile + ".snv.anno.vcf"
        bframe = onkopus.read_file(infile)
        bframe.data = onkopus.annotate_variant_data(bframe.data, genome_version="hg19", include_clinical_data=False, include_gene=False, include_acmg=False)
        #print("Write annotated file in ",outfile)
        onkopus.write_file(outfile,bframe)
        stop = time.time() - start
        print("Required time: ",stop)

        with open(outfile, 'r') as file:
            read_content = file.read()

        content_exp=('ILTER\tINFO\n'
 'chr7\t21784211\t0\tA\tAG\t0\t0\t'
 '0;chrom=7;pos_hg38=21744593;pos_hg19=21784211;ref=A;alt=AG\n'
 'chr10')

        self.assertEqual(read_content[50:150], content_exp,"")




import unittest
import onkopus as op


class TestAnnotationMultipleTypes(unittest.TestCase):

    def test_gene_annotation(self):
        data = {
            "TP53":{ "mutation_type": "gene" },
            "chr7:140753336A>T": { }
        }
        data = op.annotate_genes(data)
        print(data)




import datetime, traceback, copy
import adagenes.tools.parse_vcf
import adagenes.processing.parse_http_responses
from onkopus.conf import read_config as config
import adagenes.tools.module_requests as req

qid_key = "q_id"
error_logfile=None


class CIViCClient:

    def __init__(self, genome_version, error_logfile=None):
        self.genome_version = genome_version
        self.info_lines = config.civic_info_lines
        self.url_pattern = config.civic_src
        self.srv_prefix = config.civic_srv_prefix
        self.extract_keys = config.civic_keys

        self.qid_key = "q_id"
        self.error_logfile = error_logfile
        #if (self.genome_version == "hg19") or (self.genome_version == "GRCh37"):
        #    self.qid_key = "q_id_hg19"

    def process_data(self, vcf_lines,input_format='json'):
        json_obj = adagenes.tools.filter_wildtype_variants(vcf_lines)

        # get gene names and variant exchange from passed JSON object
        if input_format == 'vcf':
            keys = [config.uta_adapter_srv_prefix + config.concat_char + config.uta_genomic_keys[0],
                    config.uta_adapter_srv_prefix + config.concat_char + config.uta_genomic_keys[1]]
            annotations = adagenes.tools.parse_vcf.extract_annotations_vcf(json_obj, keys)
        else:
            keys = [config.uta_genomic_keys[0], config.uta_genomic_keys[1]]
            annotations = adagenes.tools.parse_vcf.extract_annotations_json(json_obj, config.uta_adapter_srv_prefix, keys)

        gene_names = copy.deepcopy(annotations[keys[0]])
        varexch = copy.deepcopy(annotations[keys[1]])
        qid_list = copy.deepcopy(annotations['q_id'])

        while True:
            max_length = int(config.config["DEFAULT"]["MODULE_BATCH_SIZE"])
            if max_length > len(qid_list):
                max_length = len(qid_list)
            qids_partial = qid_list[0:max_length]

            qids_partial = adagenes.tools.filter_alternate_alleles(qids_partial)

            genompos_str = ','.join(qids_partial)
            gene_names_partial = \
                adagenes.tools.parse_vcf.extract_annotations_json_part(json_obj, config.uta_adapter_srv_prefix,
                                                                     [config.uta_genomic_keys[0]],
                                                                     qids_partial)[config.uta_genomic_keys[0]]
            variant_exchange_partial = adagenes.tools.parse_vcf.extract_annotations_json_part(json_obj,
                                                                                            config.uta_adapter_srv_prefix, [
                                                                                                config.uta_genomic_keys[
                                                                                                    1]],
                                                                                            qids_partial)[
                config.uta_genomic_keys[1]]

            gene_names_str = ",".join(gene_names_partial)
            variant_exchange_str = ",".join(variant_exchange_partial)
            query = 'genesymbol=' + gene_names_str + '&variant=' + variant_exchange_str + '&genompos=' + genompos_str

            q = ""
            for i in range(0, len(gene_names_partial)):
                q += str(gene_names_partial[i]) + ":" + str(variant_exchange_partial[i]) + ","

            q = q.rstrip(",")
            q += '&genompos=' + genompos_str + '&key=genompos'

            #vcf_lines = adagenes.processing.parse_http_responses.parse_module_response(q, vcf_lines,self.url_pattern,self.genome_version,self.srv_prefix)
            try:
                json_body = req.get_connection(q, self.url_pattern, self.genome_version)

                for key in json_body.keys():
                    json_obj = json_body[key]
                    qid = key

                    try:
                        if "Score" in json_obj:
                            if json_obj['Score'] != '':
                                json_obj['score_percent'] = int(float(json_obj['Score']) * 100)
                            else:
                                json_obj['score_percent'] = 0
                        # json_obj.pop('q_id')
                        vcf_lines[qid][self.srv_prefix] = json_obj
                    except:
                        cur_dt = datetime.datetime.now()
                        print(cur_dt, ": error processing variant response: ", qid, ';', traceback.format_exc())
            except:
                print(": error processing variant response: ;", traceback.format_exc())

            for i in range(0, max_length):
                del gene_names[0]
                del varexch[0]
                del qid_list[0]
            if len(qid_list) == 0:
                break

        return vcf_lines



import unittest, os
import onkopus as op
import adagenes as ag


class ProteinDomainsTestCase(unittest.TestCase):

    def test_protein_domains_client_hg19(self):
        genome_version = 'hg19'
        #data = {"chr7:140453136A>T": {}}
        #data = ag.LiftoverAnnotationClient(genome_version=genome_version,target_genome="hg38").process_data(data)
        data = {"chr7:140753336A>T":{}}
        genome_version="hg38"
        data = op.uta_adapter_client.UTAAdapterClient(
            genome_version=genome_version).process_data(data)
        data = op.ProteinDomainClient(
            genome_version=genome_version).process_data(data)
        #print(data)
        expected_content = ('{"protein_acession":{"0":"BRAF;","1":"BRAF;","2":"BRAF;"},"seq_MD5_digest":{"0":"74c9b69323bd112084c1b5b385e7e6c5","1":"74c9b69323bd112084c1b5b385e7e6c5","2":"74c9b69323bd112084c1b5b385e7e6c5"},"seq_length":{"0":766,"1":766,"2":766},"analysis":{"0":"Pfam","1":"Pfam","2":"Pfam"},"sig_accession":{"0":"PF02196","1":"PF07714","2":"PF00130"},"sig_description":{"0":"Raf-like '
 'Ras-binding domain","1":"Protein tyrosine and serine\\/threonine '
 'kinase","2":"Phorbol esters\\/diacylglycerol binding domain (C1 '
 'domain)"},"start_location":{"0":157,"1":457,"2":235},"stop_location":{"0":225,"1":712,"2":281},"e_value":{"0":1.2e-23,"1":1.5e-59,"2":0.0000000006},"match_status":{"0":"T","1":"T","2":"T"},"date":{"0":"25-10-2024","1":"25-10-2024","2":"25-10-2024"},"ipr_accession":{"0":"IPR003116","1":"IPR001245","2":"IPR002219"},"ipr_description":{"0":"Raf-like '
 'Ras-binding","1":"Serine-threonine\\/tyrosine-protein kinase, catalytic '
 'domain","2":"Protein kinase C-like, phorbol ester\\/diacylglycerol-binding '
 'domain"},"go_terms":{"0":"-","1":"-","2":"-"},"pathway_annotation":{"0":"-","1":"-","2":"-"}}')
        self.assertEqual(data["chr7:140753336A>T"]["protein_domains"], expected_content, "")

    def test_protein_domain_client_cna(self):
        genome_version = 'hg19'
        # data = {"chr7:140453136A>T": {}}
        # data = ag.LiftoverAnnotationClient(genome_version=genome_version,target_genome="hg38").process_data(data)
        qid = "chr15:30103918-30644082_DUP"
        data = {qid: { "variant_data":{"CHROM":15,"POS":30103918, "POS2":30644082} }}
        genome_version = "hg38"
        #data = op.uta_adapter_client.UTAAdapterClient(
        #    genome_version=genome_version).process_data(data)
        data = op.GENCODECNAClient(genome_version=genome_version).process_data(data)
        data = op.ProteinDomainCNAClient(
            genome_version=genome_version).process_data(data)
        # print(data)
        expected_content = {'CHRFAM7A': '{"protein_acession":{"0":"CHRFAM7A;","1":"CHRFAM7A;"},"seq_MD5_digest":{"0":"c6c9eb6631ad75594b2ca964296df951","1":"c6c9eb6631ad75594b2ca964296df951"},"seq_length":{"0":412,"1":412},"analysis":{"0":"Pfam","1":"Pfam"},"sig_accession":{"0":"PF02932","1":"PF02931"},"sig_description":{"0":"Neurotransmitter-gated '
             'ion-channel transmembrane region","1":"Neurotransmitter-gated '
             'ion-channel ligand binding '
             'domain"},"start_location":{"0":147,"1":28},"stop_location":{"0":396,"1":140},"e_value":{"0":4.9e-58,"1":1.9e-29},"match_status":{"0":"T","1":"T"},"date":{"0":"27-10-2024","1":"27-10-2024"},"ipr_accession":{"0":"IPR006029","1":"IPR006202"},"ipr_description":{"0":"Neurotransmitter-gated '
             'ion-channel transmembrane domain","1":"Neurotransmitter-gated '
             'ion-channel ligand-binding '
             'domain"},"go_terms":{"0":"-","1":"-"},"pathway_annotation":{"0":"-","1":"-"}}',
 'GOLGA8R': '{"protein_acession":{"0":"GOLGA8R;","1":"GOLGA8R;","2":"GOLGA8R;"},"seq_MD5_digest":{"0":"110809df137b429e351f1e9bd0f30bdf","1":"110809df137b429e351f1e9bd0f30bdf","2":"110809df137b429e351f1e9bd0f30bdf"},"seq_length":{"0":631,"1":631,"2":631},"analysis":{"0":"Pfam","1":"Pfam","2":"Pfam"},"sig_accession":{"0":"PF19046","1":"PF15070","2":"PF15070"},"sig_description":{"0":"GM130 '
            'C-terminal binding motif","1":"Putative golgin subfamily A member '
            '2-like protein 5","2":"Putative golgin subfamily A member 2-like '
            'protein '
            '5"},"start_location":{"0":594,"1":365,"2":226},"stop_location":{"0":631,"1":493,"2":364},"e_value":{"0":0.0,"1":0.0000000063,"2":2e-19},"match_status":{"0":"T","1":"T","2":"T"},"date":{"0":"28-10-2024","1":"28-10-2024","2":"28-10-2024"},"ipr_accession":{"0":"IPR043937","1":"IPR043976","2":"IPR043976"},"ipr_description":{"0":"Golgin '
            'subfamily A member 2, C-terminal binding motif","1":"Golgin '
            'subfamily A, conserved domain","2":"Golgin subfamily A, conserved '
            'domain"},"go_terms":{"0":"-","1":"-","2":"-"},"pathway_annotation":{"0":"-","1":"-","2":"-"}}'}
        self.assertEqual(data[qid]["protein_domains"], expected_content, "")





import onkopus as op
from onkopus.processing.parallel_cna_requests import parallel_requests, parallel_requests1


def annotate_cnas(
        annotated_data,
        genome_version="hg38",
        tumor_type=None,
        request_id=None,include_clinical_data=True,
                  include_gene=True,
                  include_acmg=True):
    """
    Annotates a gene with associated Onkopus modules

    :param annotated_data:
    :param gene:
    :param genome_version:
    :return:
    """
    #print("Annotate CNAS")

    # get genes from biomarker data
    gene_data = {}
    #print(annotated_data)
    for var in annotated_data.keys():
        mut_type = ""

        if "variant_data" in annotated_data[var]:
            if "mutation_type" in annotated_data[var]["variant_data"]:
                mut_type = annotated_data[var]["variant_data"]["mutation_type"]
            elif "mutation_type" in annotated_data[var]:
                mut_type = annotated_data[var]["mutation_type"]
        elif "mutation_type" in annotated_data[var]:
            mut_type = annotated_data[var]["mutation_type"]
        if mut_type == "cnv":
            gene_data[var] = annotated_data[var]

    #print("cna data keys ",gene_data)
    if len(list(gene_data.keys())) > 0:
        gene_data = parallel_requests(gene_data, genome_version=genome_version)

        gene_data = parallel_requests1(gene_data)


    for var in gene_data.keys():
        annotated_data[var] = gene_data[var]

        #annotated_data[var]["UTA_Adapter"] = { "gene_name": var }

    #return annotated_data
    return gene_data



import unittest
import adagenes
import onkopus as op


class TestMutationType(unittest.TestCase):

    def test_split_by_mutation_type(self):

        data = { "chr7:140753336A>T": {}, "TP53": {}, "NRAS:Q61L":{} }
        bframe = adagenes.BiomarkerFrame(data=data,genome_version="hg38")
        data = adagenes.recognize_biomarker_types(bframe).data
        print(data)
        dc = op.split_data_by_mutation_type(data)
        print(dc)





from .annotate_variants import *
from .gene_request import *
from .snv_request import *
from .fusion_request import *
from .gene_request import *
from .indel_request import *
from .cna_request import *
from .annotate import *



import unittest, copy
import adagenes
import onkopus.onkopus_clients

class MVPAnnotationTestCase(unittest.TestCase):

    def test_mvp_client(self):
        genome_version = 'hg19'

        #infile = "../test_files/somaticMutations.vcf"
        infile = "../test_files/somaticMutations.ln_12.vcf"
        outfile = "../test_files/somaticMutations.ln_12.tsv.mvp"
        #data = onkopus.VCFReader(genome_version).read_file(infile)

        #data.data = onkopus.onkopus_clients.MVPClient(
        #    genome_version=genome_version).process_data(data.data)

        #print("Response ",data.data)
        #mapping = { "variant_data": ["POS_hg19","POS_hg38"]
        #         }
        #onkopus.TSVWriter().write_to_file(outfile,data,mapping=mapping)

    def test_mvp_client_hg38(self):
        genome_version = 'hg38'
        data = {"chr7:140753336A>T": {}, "chr10:8073950C>T": {}}
        #for var in data:
        #    data[var] = onkopus.generate_variant_data_section(data[var])
        #print(data)

        #data = onkopus.onkopus_clients.LiftOverClient(genome_version=genome_version).process_data(data)
        data = adagenes.LiftoverClient(genome_version=genome_version).process_data(data)

        print(data)
        data = onkopus.onkopus_clients.MVPClient(
            genome_version=genome_version).process_data(data)

        print("Response ",data)





import traceback, datetime, json, copy
from onkopus.conf import read_config as conf_reader
import requests
from json import JSONDecodeError
import adagenes as ag


class GeneExpressionClient:

    def __init__(self, error_logfile=None):
        #self.genome_version = genome_version
        self.info_lines= conf_reader.ge_module_info_lines
        self.url_pattern = conf_reader.ge_module_src
        self.srv_prefix = conf_reader.ge_module_srv_prefix
        self.response_keys = conf_reader.ge_module_response_keys
        self.extract_keys = conf_reader.ge_module_keys

        self.qid_key = "q_id"
        self.error_logfile = error_logfile

    def process_data(self, variant_data):
            """
            Generates JSON data for a Plotly variant needleplot with added variant annotations

            :param variant_data:
            :return:
            """
            vcf_linesf = ag.tools.filter_wildtype_variants(variant_data)

            qid_list0 = copy.deepcopy(list(vcf_linesf.keys()))

            qid_gene_mapping = {}
            qid_list = []
            genes = []
            variants = []
            for var in qid_list0:
                var_orig = var

                if "UTA_Adapter" in variant_data[var_orig]:
                    if "gene_name" in variant_data[var_orig]["UTA_Adapter"]:
                        gene = variant_data[var_orig]["UTA_Adapter"]["gene_name"]
                        genes.append(variant_data[var_orig]["UTA_Adapter"]["gene_name"])
                        variants.append(variant_data[var_orig]["UTA_Adapter"]["variant_exchange"])
                        qid_list.append(var)

                        if gene not in qid_gene_mapping.keys():
                            qid_gene_mapping[gene] = []
                        qid_gene_mapping[gene].append(var_orig)
                    else:
                        pass
                elif "UTA_Adapter_gene_name" in variant_data[var_orig].keys():
                    genes.append(variant_data[var_orig]["UTA_Adapter_gene_name"])
                    variants.append(variant_data[var_orig]["UTA_Adapter_variant_exchange"])
                    qid_list.append(var)
                    gene = variant_data[var_orig]["UTA_Adapter_gene_name"]
                    if gene not in qid_gene_mapping.keys():
                        qid_gene_mapping[gene] = []
                    qid_gene_mapping[gene].append(var_orig)
                elif "hgnc_gene_symbol" in variant_data[var_orig].keys():
                    genes.append(variant_data[var_orig]["hgnc_gene_symbol"])
                    variants.append(variant_data[var_orig]["aa_exchange"])
                    qid_list.append(var)
                    gene = variant_data[var_orig]["hgnc_gene_symbol"]
                    if gene not in qid_gene_mapping.keys():
                        qid_gene_mapping[gene] = []
                    qid_gene_mapping[gene].append(var_orig)
                # elif "INFO" in variant_data[var].keys():
                #    pass
                elif "info_features" in variant_data[var_orig].keys():
                    # print("INFO ok")
                    # print(variant_data[var]["info_features"])
                    if "UTA_Adapter_gene_name" in variant_data[var_orig]["info_features"]:
                        genes.append(variant_data[var_orig]["info_features"]["UTA_Adapter_gene_name"])
                        variants.append(variant_data[var_orig]["info_features"]["UTA_Adapter_variant_exchange"])
                        qid_list.append(var)
                        gene = variant_data[var_orig]["info_features"]["UTA_Adapter_gene_name"]
                        if gene not in qid_gene_mapping.keys():
                            qid_gene_mapping[gene] = []
                        qid_gene_mapping[gene].append(var_orig)
                elif "mutation_type" in variant_data[var]:
                    if variant_data[var_orig]["mutation_type"] == "gene":
                        qid_list.append(var)
                        genes.append("")
                        variants.append("")

                        if var not in qid_gene_mapping.keys():
                            qid_gene_mapping[var_orig] = []
                        qid_gene_mapping[var_orig].append(var)

            
            #qid_gene_mapping = {}
            #qid_list = []
            #for var in variant_data.keys():
            #    if "UTA_Adapter" in variant_data[var]:
            #        if ("gene_name" in variant_data[var]["UTA_Adapter"]):
            #            qid_list.append(variant_data[var]["UTA_Adapter"]["gene_name"])
            #            if variant_data[var]["UTA_Adapter"]["gene_name"] not in qid_gene_mapping.keys():
            #                qid_gene_mapping[variant_data[var]["UTA_Adapter"]["gene_name"]] = []

            #            qid_gene_mapping[variant_data[var]["UTA_Adapter"]["gene_name"]].append(var)
            #    elif "mutation_type" in variant_data[var]:
            #        if variant_data[var]["mutation_type"] == "gene":
            #            qid_list.append(var)

            #            if var not in qid_gene_mapping.keys():
            #                qid_gene_mapping[var] = []
            #            qid_gene_mapping[var].append(var)

            #qid_lists_query = ag.tools.split_list(qid_list)
            qid_lists_query = ag.tools.split_list(qid_list)
            genes_lists_query = ag.tools.split_list(genes)
            variants_lists_query = ag.tools.split_list(variants)

            for i,qid_list in enumerate(qid_lists_query):
                gene_list = genes_lists_query[i]
                url = conf_reader.ge_module_src + "?gene=" + ",".join(gene_list).rstrip(",")
                print(url)
                json_body = (requests.get(url, timeout=60))
                json_body = json_body.json()
                try:
                    for gene in json_body.keys():
                        if gene != "":
                            for associated_var in qid_gene_mapping[gene]:
                                variant_data[associated_var]["gtex"] = json_body[gene][0]
                except:
                    print(traceback.format_exc())

            return variant_data



import unittest, copy, os
import onkopus.onkopus_clients
import adagenes


class REVELAnnotationTestCase(unittest.TestCase):

    def test_revel_client(self):
        genome_version = 'hg38'

        data = {"chr7:140753336A>T": {}, "chr10:8115913C>T": {}}

        variant_data = onkopus.onkopus_clients.REVELClient(
            genome_version=genome_version).process_data(data)

        print("Response ",variant_data)

    def test_revel_client_file(self):
        __location__ = os.path.realpath(
            os.path.join(os.getcwd(), os.path.dirname(__file__)))
        infile = __location__ + "/../../test_files/somaticMutations.ln50.vcf"
        outfile = __location__ + "/../../test_files/somaticMutations.ln50.revel.csv"
        bframe = adagenes.read_file(infile)
        genome_version = 'hg19'
        bframe = adagenes.LiftoverClient(genome_version=genome_version).process_data(bframe)
        bframe.data = onkopus.onkopus_clients.REVELClient(
            genome_version=genome_version).process_data(bframe.data)
        print(bframe.data)
        mapping = { "revel":"Score","variant_data":["CHROM","POS","REF","ALT"] }
        labels = {"revel":"revel_Score", "CHROM":"variant_data_CHROM", "POS":"variant_data_POS", "REF":"variant_data_REF", "ALT":"variant_data_ALT"}
        ranked_labels = ["CHROM","POS","REF","ALT","revel"]
        adagenes.write_file(outfile,bframe,mapping=mapping,labels=labels,ranked_labels=ranked_labels)



import datetime, traceback, copy
import adagenes.tools.parse_vcf
import adagenes.tools.module_requests as req
from onkopus.conf import read_config as config

qid_key = "q_id"
error_logfile=None


class CIViCNearbyClient:
    def __init__(self, genome_version, error_logfile=None):
        self.genome_version = genome_version
        self.info_lines = config.civic_info_lines
        self.url_pattern = config.civic_gene_src
        self.srv_prefix = config.civic_srv_prefix
        self.extract_keys = config.civic_keys

        self.qid_key = "q_id"
        self.error_logfile = error_logfile
        #if (self.genome_version == "hg19") or (self.genome_version == "GRCh37"):
        #    self.qid_key = "q_id_hg19"

    def process_data(self, vcf_lines,input_format='json'):

        qid_list = list(vcf_lines.keys())

        while True:
            max_length = int(config.config["DEFAULT"]["MODULE_BATCH_SIZE"])
            if max_length > len(qid_list):
                max_length = len(qid_list)
            qids_partial = qid_list[0:max_length]

            q = ",".join(qids_partial)
            #for i in range(0, len(qids_partial)):
            #    q += str(qids_partial[i]) + ":" + str(variant_exchange_partial[i]) + ","

            q = q.rstrip(",")

            try:
                json_body = req.get_connection(q, self.url_pattern, self.genome_version)

                for key in json_body.keys():
                        json_obj = json_body[key]
                        qid=key

                        for k in self.extract_keys:
                            if k in json_obj:
                                pass
                                #annotations.append('{}_{}={}'.format(self.srv_prefix, k, json_body[i][k]))
                        try:
                            #json_obj.pop('q_id')
                            vcf_lines[qid][self.srv_prefix] = json_obj
                        except:
                            if self.error_logfile is not None:
                                cur_dt = datetime.datetime.now()
                                date_time = cur_dt.strftime("%m/%d/%Y, %H:%M:%S")
                                print(cur_dt, ": error processing variant response: ", qid, ';', traceback.format_exc(), file=self.error_logfile+str(date_time)+'.log')
                            else:
                                print(cur_dt, ": error processing variant response: ", qid, ';', traceback.format_exc())
            except:
                print(": error processing variant response: ;", traceback.format_exc())
                if error_logfile is not None:
                    print("error processing request: ", annotations, file=error_logfile+str(date_time)+'.log')

            for i in range(0, max_length):
                del qid_list[0]
            if len(qid_list) == 0:
                break

        return vcf_lines



import datetime, traceback, copy
import adagenes.tools.parse_vcf
import adagenes as ag
from onkopus.conf import read_config as config

qid_key = "q_id"
error_logfile=None

class LoFToolClient:
    def __init__(self, genome_version, error_logfile=None):
        self.genome_version = genome_version
        self.info_lines = config.loftool_info_lines
        self.url_pattern = config.loftool_src
        self.srv_prefix = config.loftool_srv_prefix
        self.extract_keys = config.loftool_keys

        self.qid_key = "q_id"
        self.error_logfile = None
        #if (self.genome_version == "hg19") or (self.genome_version == "GRCh37"):
        #    self.qid_key = "q_id_hg19"

    def process_data(self, vcf_lines, input_format='json'):
        vcf_linesf = ag.tools.filter_wildtype_variants(vcf_lines)

        qid_dc = {}
        if self.genome_version == "hg38":
            qid_list0 = copy.deepcopy(list(vcf_linesf.keys()))
        else:
            qid_dc, qid_list0 = ag.tools.generate_qid_list_from_other_reference_genome(vcf_linesf)
            self.genome_version = "hg38"
            retransform = True
        #qid_dc, qid_list0 = ag.tools.generate_qid_list_from_other_reference_genome(vcf_linesf)
        self.genome_version = "hg38"

        qid_list = []
        genes = []
        variants = []
        for var in qid_list0:
            if var in qid_dc.keys():
                qid_orig = qid_dc[var]
            else:
                qid_orig = var
            #qid_orig = qid_dc[var]
            var_orig = qid_orig

            if "UTA_Adapter" in vcf_lines[var_orig]:
                if "gene_name" in vcf_lines[var_orig]["UTA_Adapter"]:
                    genes.append(vcf_lines[var_orig]["UTA_Adapter"]["gene_name"])
                    variants.append(vcf_lines[var_orig]["UTA_Adapter"]["variant_exchange"])
                    qid_list.append(var)
                else:
                    pass
            elif "UTA_Adapter_gene_name" in vcf_lines[var_orig].keys():
                genes.append(vcf_lines[var_orig]["UTA_Adapter_gene_name"])
                variants.append(vcf_lines[var_orig]["UTA_Adapter_variant_exchange"])
                qid_list.append(var)
            elif "hgnc_gene_symbol" in vcf_lines[var_orig].keys():
                genes.append(vcf_lines[var_orig]["hgnc_gene_symbol"])
                variants.append(vcf_lines[var_orig]["aa_exchange"])
                qid_list.append(var)
            # elif "INFO" in vcf_lines[var].keys():
            #    pass
            elif "info_features" in vcf_lines[var_orig].keys():
                # print("INFO ok")
                # print(vcf_lines[var]["info_features"])
                if "UTA_Adapter_gene_name" in vcf_lines[var_orig]["info_features"]:
                    genes.append(vcf_lines[var_orig]["info_features"]["UTA_Adapter_gene_name"])
                    variants.append(vcf_lines[var_orig]["info_features"]["UTA_Adapter_variant_exchange"])
                    qid_list.append(var)

        qid_lists_query = ag.tools.split_list(qid_list)
        genes_lists_query = ag.tools.split_list(genes)
        variants_lists_query = ag.tools.split_list(variants)

        for qlist, glist, vlist in zip(qid_lists_query, genes_lists_query, variants_lists_query):
            q_genes = ",".join(glist)
            q_variants = ",".join(vlist)
            q_genompos = ",".join(qlist)

            #max_length = int(config.config["DEFAULT"]["MODULE_BATCH_SIZE"])
            #if max_length > len(qid_list):
            #    max_length = len(qid_list)
            #qids_partial = qid_list[0:max_length]
            #qids_partial = adagenes.tools.filter_alternate_alleles(qids_partial)
            #genompos_str = ','.join(qids_partial)
            #gene_names_partial = \
            #    adagenes.tools.parse_vcf.extract_annotations_json_part(vcf_lines, config.uta_adapter_srv_prefix,[config.uta_genomic_keys[0]],
            #                                                         qids_partial)[config.uta_genomic_keys[0]]
            #gene_names_str = ",".join(gene_names_partial)
            #q = 'genesymbol=' + gene_names_str + '&genompos=' + genompos_str
            q = "genompos=" + q_genompos + "&genesymbol=" + q_genes + "&variant=" + q_variants

            vcf_lines = adagenes.processing.parse_http_responses.parse_module_response(q, vcf_lines, self.url_pattern,
                                                                                     self.genome_version,
                                                                                     self.srv_prefix,
                                                                                       qid_dc)

            #for i in range(0,max_length):
            #    #del gene_names[0] #gene_names.remove(qid)
            #    #del variant_exchange[0]  #variant_exchange.remove(qid)
            #    del qid_list[0] # qid_list.remove(qid)
            #if len(qid_list) == 0:
            #    break

        return vcf_lines




import unittest,os
import adagenes
import onkopus as op


class TreatmentExportTestCase(unittest.TestCase):

    def test_export_treatment_data(self):
        __location__ = os.path.realpath(
            os.path.join(os.getcwd(), os.path.dirname(__file__)))
        oncokb_key = os.getenv("ONCOKB_KEY")

        data = {"chr7:140753336A>T":{}, "chr17:7673776G>A":{}}
        genome_version = "hg38"
        bf = adagenes.BiomarkerFrame(genome_version=genome_version,data=data)
        bf = op.annotate(bf, genome_version="hg38",oncokb_key=oncokb_key)

        outfile=__location__ + "/../test_files/test_writer.out.csv"
        op.ClinSigWriter().write_evidence_data_to_file(bf,outfile,sep="\t")

        file = open(outfile, 'r')
        contents = file.read()
        contents_expected = """biomarker\tcitation_i"""
        self.assertEqual(contents[0:20], contents_expected, "")
        file.close()



    def test_export_treatment_data_opened_file(self):
        __location__ = os.path.realpath(
            os.path.join(os.getcwd(), os.path.dirname(__file__)))
        oncokb_key = os.getenv("ONCOKB_KEY")

        data = {"chr7:140753336A>T":{}, "chr17:7673776G>A":{}}
        genome_version = "hg38"
        bf = adagenes.BiomarkerFrame(genome_version=genome_version,data=data)
        bf = op.annotate(bf, genome_version="hg38",oncokb_key=oncokb_key)
        bf.data = op.DrugOnClient(genome_version=genome_version).process_data(bf.data)

        #print(bf.data["chr7:140753336A>T"]["oncokb"])

        outfile_str=__location__ + "/../test_files/test_writer.out.stream.csv"
        outfile = open(outfile_str, "w")
        op.ClinSigWriter().write_evidence_data_to_file_all_features(bf,outfile=outfile,sep="\t")
        outfile.close()

        #file = open(outfile_str)
        #contents = file.read()

        with open(outfile_str, 'r') as file:
            contents = file.read()

        contents_expected = 'biomarker\tcitation_id\tcitation_url\tdisease\tdisease_normalized\tdrugs\t'\
 'evidence_level\tevidence_level_onkopus\tevidence_statement\tevidence_type\t'\
 'match_type\tmatch_type_str\tresponse\tscore\tsource\tsource_link\tsources\t'\
 'gene\tid\tpublication\tvariant_exchange\tUTA_Adapter.gene_name\t'\
 'UTA_Adapter.variant_exchange\tdrug_class\n'\
 '"BRAF V600E"\t"26678033"\t"http://www.ncbi.nlm.nih.gov/pubmed/26678033"\t'\
 '"Melanoma"\t"Melanoma"\t"D'
        self.assertEqual(contents[0:400], contents_expected, "")
        #file.close()

    def test_export_treatment_data_filestream(self):
        __location__ = os.path.realpath(
            os.path.join(os.getcwd(), os.path.dirname(__file__)))
        oncokb_key = os.getenv("ONCOKB_KEY")

        data = {"chr7:140753336A>T":{}, "chr17:7673776G>A":{}}
        genome_version = "hg38"
        bf = adagenes.BiomarkerFrame(genome_version=genome_version,data=data)
        bf = op.annotate(bf, genome_version="hg38",oncokb_key=oncokb_key)

        #print(bf.data["chr7:140753336A>T"]["oncokb"])

        import io
        import pandas as pd
        outfile_str=__location__ + "/../test_files/test_writer.out.stream.csv"
        outfile = io.StringIO()
        op.ClinSigWriter().write_evidence_data_to_file_all_features(bf,outfile=outfile,sep="\t")

        outfile.seek(0)
        df = pd.read_csv(outfile, sep="\t", names=range(12))
        #print("TREATMENTS ",df)
        outfile.close()



